summaryrefslogtreecommitdiffstats
path: root/agent/polkitqt1-agent-listener.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'agent/polkitqt1-agent-listener.cpp')
-rw-r--r--agent/polkitqt1-agent-listener.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/agent/polkitqt1-agent-listener.cpp b/agent/polkitqt1-agent-listener.cpp
index c6bf63cba..e6e3a9b00 100644
--- a/agent/polkitqt1-agent-listener.cpp
+++ b/agent/polkitqt1-agent-listener.cpp
@@ -1,5 +1,5 @@
/*
* This file is part of the Polkit-qt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,16 +18,16 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-agent-listener.h"
+#include "polkittqt1-agent-listener.h"
#include <TQtCore/TQDebug>
-#include "polkitqtlistener_p.h"
+#include "polkittqtlistener_p.h"
-#include "polkitqt1-authority.h"
-#include "polkitqt1-subject.h"
-#include "polkitqt1-identity.h"
-#include "polkitqt1-details.h"
+#include "polkittqt1-authority.h"
+#include "polkittqt1-subject.h"
+#include "polkittqt1-identity.h"
+#include "polkittqt1-details.h"
namespace PolkitTQt1
{
@@ -39,7 +39,7 @@ class ListenerPrivate
{
public:
PolkitAgentListener *listener;
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
void *registeredHandle;
#endif
};
@@ -49,7 +49,7 @@ Listener::Listener(TQObject *parent)
{
g_type_init();
- d->listener = polkit_qt_listener_new();
+ d->listener = polkit_tqt_listener_new();
tqDebug() << "New PolkitAgentListener " << d->listener;
@@ -69,7 +69,7 @@ Listener::~Listener()
tqDebug("Destroying listener");
ListenerAdapter::instance()->removeListener(this);
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
if (d->registeredHandle) {
polkit_agent_listener_unregister(d->registeredHandle);
}
@@ -83,7 +83,7 @@ bool Listener::registerListener(const PolkitTQt1::Subject &subject, const TQStri
{
GError *error = NULL;
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
d->registeredHandle = polkit_agent_listener_register(d->listener,
POLKIT_AGENT_REGISTER_FLAGS_NONE,
#else
@@ -91,7 +91,7 @@ bool Listener::registerListener(const PolkitTQt1::Subject &subject, const TQStri
#endif
subject.subject(),
objectPath.toAscii().data(),
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
NULL,
#endif
&error);
@@ -101,7 +101,7 @@ bool Listener::registerListener(const PolkitTQt1::Subject &subject, const TQStri
g_error_free(error);
return false;
}
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
if (d->registeredHandle == NULL) {
tqWarning() << TQString("Cannot register authentication agent!");
return false;
@@ -121,4 +121,4 @@ const PolkitAgentListener *Listener::listener()
}
-#include "polkitqt1-agent-listener.moc"
+#include "polkittqt1-agent-listener.moc"
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*